package com.zenithsistemas.jXHTML;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class Element {	
	
	protected HashMap attrs  = new HashMap();
	protected String prepend = "";
	protected String append  = "";
	protected String content = "";
	protected String decorator = "p";
	protected String tag = "";
	protected boolean simpleTag = false;
	protected List<String> defaultAttrs = new ArrayList();
	protected List<Element> elements = new ArrayList();
	
	public Element() {
		setup("", new HashMap());	
	}
	
	public Element(String name) {
		setup(name, new HashMap());	
	}
	
	public Element(String id, HashMap attrs) {
		setup(id, attrs);
	}
	
	public void setup(String id, HashMap attrs) {
		addDefaultAttr("name");
		addDefaultAttr("id");
		
		for(int i = 0; i < defaultAttrs.size(); i++) {
			setAttr(defaultAttrs.get(i).toString(), id);
		}		
		
		setAttrs(attrs);	
	}
	
	public void setElements(List<Element> elements) {
		this.elements = elements;
	}
	
	public void addElement(Element element) {
		elements.add(element);
	}
	
	public String render() {		
		String xhtml = "";
		
		if(decorator.length() > 0) {
			xhtml += "<" + decorator + ">";
		}
		
		xhtml += prepend;
	
		if(tag.length() > 0) {			
			xhtml += "<" + tag + getAttrs();
			
			if(simpleTag) {
				xhtml += " />";
			} else {
				xhtml += ">" + content + "</" + tag + ">"; 
			}
		}
		
		xhtml += append;
		
		if(decorator.length() > 0) {
			xhtml += "</" + decorator + ">";
		}
		
		return xhtml;
	}
	
	public void setContent(String content) {
		this.content = content;
	}
	
	public String getContent() {
		return content;
	}
	
	public void prepend(String xhtml) {
		prepend += xhtml;
	}
	
	public void prepend(Element xhtml) {
		prepend += xhtml.render();
	}
	
	public void append(String xhtml) {
		append += xhtml;
	}
	
	public void append(Element xhtml) {
		append += xhtml.render();
	}
	
	public void setAttr(String attr, String name) {
		attrs.put(attr,	filterXSS(name));
	}
	
	public String getAttr(String key) {
		return (String) attrs.get(key);
	}
	
	public void setAttrs(HashMap attrs) {
		this.attrs.putAll(attrs);
	}
	
	public String getAttrs() {		
		String result = "";
		Iterator j = attrs.entrySet().iterator();
		
		while(j.hasNext()) {
			Map.Entry pairs = (Map.Entry) j.next();
			result += " " + pairs.getKey() + "=\"" + pairs.getValue() + "\"";
		}
		
		return result;
	}
	
	public void removeAttr(String attr) {
		attrs.remove(attr);
	}
	
	public void setDefaultAttrs(List<String> attrs) {
		defaultAttrs = attrs;
	}
	
	public List<String> getDefaultAttrs() {
		return defaultAttrs;
	}
	
	public void addDefaultAttr(String attr) {
		defaultAttrs.add(attr);
	}
	
	public void removeDefaultAttr(String attr) {
		defaultAttrs.remove(attr);
	}
	
	public void setValue(String value) {
		attrs.put("value", filterXSS(value));
	}
	
	public String getValue() {
		return attrs.get("value").toString();
	}
	
	public void setId(String id) {
		attrs.put("id", filterXSS(id));
	}
	
	public String getId() {
		return attrs.get("id").toString();
	}
		
	public void setTag(String tag) {
		this.tag = tag;
	}
	
	public String getTag() {		
		return tag;
	}
	
	public void setDecorator(Element decorator) {
		this.decorator = decorator.getTag();
	}
	
	public void setDecorator(String decorator) {
		this.decorator = decorator;
	}
		
	public String getDecorator() {
		return decorator;
	}
	
	public void clearDecorator() {
		decorator = "";
	}
	
	public void setSimpleTag() {
		simpleTag = true;
	}
	
	public String filterXSS(String str) {
		return str.replaceAll("\\<", "&lt;")
		 .replaceAll("\\>", "&gt;")
		 .replaceAll("\\\"", "&quot;");
	}
	
	public String toString() {
		return render();
	}
	
	public String toString(Object obj) {
		return render();
	}
	
	public boolean equals(Element obj) {
		return tag == obj.getTag();
	}	
}